@@ -1,9 +1,9 @@
 import os
 import logging
 
-from analizer import Analizer
-from rubyCodeParser import RubyCodeParser
-from rubyFolderVerify import RubyFolderVerify
+from .analizer import Analizer
+from .rubyCodeParser import RubyCodeParser
+from .rubyFolderVerify import RubyFolderVerify
 
 
 logger = logging.getLogger('Formatter')
