@@ -2,7 +2,7 @@ import logging
 
 from .fileFormatter import FileFormatter
 from .cmdParser import CmdParser
-import log
+# import .log
 
 
 logger = logging.getLogger('Formatter')
